# mipidsi

This crate provides a generic display driver to connect to TFT displays
that implement the [MIPI DSI](https://www.mipi.org/specifications/dsi).

Uses [display_interface](https://crates.io/crates/display-interface) to talk to the hardware.

An optional batching of draws is supported via the `batch` feature (default on)

## Architecture

The `Display` driver itself contains most of the functionality. Each specific display model implements the `Model` trait for every color format it supports.

[embedded-graphics-core](https://crates.io/crates/embedded-graphics-core) is used to provide the drawing API.

## Models

Each supported display model can be used either through the `Display::with_model` call or through a shortcut function such as `Display::st7789` if provided (only available to in-tree models, external crate models must use the `with_model` constructor).

### Example
```rust
// create a DisplayInterface from SPI and DC pin, with no manual CS control
let di = SPIInterfaceNoCS::new(spi, dc);
// create the ILI9486 display driver in rgb666 color mode from the display interface and RST pin
let mut display = Display::ili9486_rgb666(di, rst);
display.init(&mut delay::Ets, DisplayOptions::default())?;
// clear the display to black
display.clear(Rgb666::BLACK)?;
```

License: MIT

## Minimum Supported Rust Version (MSRV)

This crate is guaranteed to compile on stable Rust 1.59.0 and up. It *might*
compile with older versions but that may change in any new patch release.
